@@ -1,10 +1,15 @@
-import ctypes
-from re import I
+try:
+    import ctypes
+except:
+    pass
 import tkinter as tk
 import tkinter.ttk as ttk
-from ctypes import POINTER, Structure, windll
-from ctypes.wintypes import DWORD, ULONG, BOOL, HRGN
 
+try:
+    from ctypes import POINTER, Structure, windll
+    from ctypes.wintypes import DWORD, ULONG, BOOL, HRGN
+except:
+    pass
 from enum import Enum
 
 from tkdev4.devplyer import set_auto_install_plyer, install_plyer, DevNotification, DevEmail
@@ -28,15 +33,8 @@ except ImportError:
 try:
     import darkdetect
 except ImportError:
-    pass
+    pas
 
-dwm = windll.dwmapi
-gdi = windll.gdi32
-user = windll.user32
-SetWindowCompositionAttribute = windll.user32.SetWindowCompositionAttribute
-SetWindowCompositionAttribute()
-windll.shcore.SetProcessDpiAwareness(1)
-ScaleFactor = windll.shcore.GetScaleFactorForDevice(0)
 
 try:
     taskbar_height = GetMonitorInfo(MonitorFromPoint((0, 0))).get("Monitor")[3] - \
@@ -363,15 +361,6 @@ class DevManage(object):
         self.rgbBlack = 0x00000000
         self.rgbWhite = 0x00FFFFFF
 
-    def get_rgb(self, red: int, green: int, blue: int):
-        from ctypes.wintypes import RGB
-        return RGB(red, green, blue)
-
-    def get_hex(self, hex: int):
-        from PIL import ImageColor
-        color = ImageColor.getcolor(hex, "RGB")
-        return self.get_rgb(color[0], color[1], color[2])
-
     def high_dpi(self):
         try:
             self.Shcore.SetProcessDpiAwareness(2)
@@ -395,6 +384,16 @@ class DevManage(object):
             size
         )
 
+    def dwm_get_window_attribute(self, type, size):
+        """
+        用于对非客户区进行设置。
+        """
+        return self.DwmGetWindowAttribute(
+            self._master,
+            type,
+            size
+        )
+
     def dwm_set_window_attribute_use_dark_mode(self):
         """
         设置窗口主题为黑暗模式，标题栏会有所改变。
@@ -406,6 +405,16 @@ class DevManage(object):
             ctypes.sizeof(Value)
         )
 
+    def dwm_get_window_attribute_use_dark_mode(self):
+        """
+        设置窗口主题为黑暗模式，标题栏会有所改变。
+        """
+        Value = ctypes.c_int(self.DWMWA_USE_IMMERSIVE_DARK_MODE)
+        self.dwm_get_window_attribute(
+            self.DWMWA_USE_IMMERSIVE_DARK_MODE,
+            ctypes.sizeof(Value)
+        )
+
     def dwm_set_window_attribute_use_light_mode(self):
         """
         设置窗口主题为明亮模式，标题栏会有所改变。
@@ -1478,7 +1487,7 @@ class DevTabbar(tk.Frame):
 
 
 class DevWindow(tk.Tk):
-    def __init__(self, title: str = "", size=(630,300), icon=Icon_Empty):
+    def __init__(self, title: str = "", size=(630, 300), icon=Icon_Empty):
         """
         快捷使用窗口，内置多种功能，快速使用
         """
@@ -1606,7 +1615,7 @@ class DevWindow(tk.Tk):
 
 
 class DevToplevel(tk.Toplevel, DevWindow):
-    def __init__(self, master:tk.Tk, title: str = "", size=(630,300), icon=Icon_Empty):
+    def __init__(self, master: tk.Tk, title: str = "", size=(630, 300), icon=Icon_Empty):
         super(DevToplevel, self).__init__(master=master)
         self.title(title)
         self.geometry(f"{size[0]}x{size[1]}")
@@ -1728,8 +1737,8 @@ class DevTooltip(DevToplevel):
 
 
 if __name__ == '__main__':
-    root = DevWindow()
-    tray = DevTray(root, icon=ICON_APPLICATION, icon_mode="load")
-    DevNotification(title="demo", message="你好，我是消息提示").show()
-    tray.show()
-    root.mainloop()
\ No newline at end of file
+    Window = DevWindow()
+    Manage = DevManage(Window)
+    Manage.dwm_set_window_attribute_use_dark_mode()
+    Window.after(100, lambda: print(Manage.dwm_get_window_attribute_use_dark_mode()))
+    Window.mainloop()
